@@ -42,6 +42,12 @@ public:
     void setTextToolsEnabled(bool on);
     void deselectAllAnnotationActions();
 
+signals:
+    void ephemeralStampWarning();
+
+private slots:
+    void slotAnnotationToolBarVisibilityChanged(bool visible);
+
 private:
     class AnnotationActionHandlerPrivate *d;
 };
